# Index view of Amplitude Vectors

ivav is tool to simulate quantum circuit using indices of the amplitude vectors. ivav is motivated from [Bernstein’s Invited Talk at Indocrypt 2021](https://cr.yp.to/talks.html).

<!-- and Dr. Dhiman Saha who taught [CS614: Quantum Symmetric-Key Cryptanalysis](https://www.iitbhilai.ac.in/index.php?pid=dhiman). -->

# Getting Started

Install Python and virtual env. Then follow the below steps.

```
git clone https://github.com/Gopal-Dahale/ivav.git
cd ivav
virtualenv venv
.
.
.
.venv/bin/activate
pip install -r requirements.txt
pip install -e .
```

```
pip install ivav
```

# Testing

To run tests, run the following command in your virutalenv

```
pip install -e .[dev]
pytest
```
